@@ -21,6 +21,7 @@ import os
 import pkg_resources
 import pprint
 import re
+import site
 import subprocess
 import sys
 import webbrowser
@@ -36,7 +37,7 @@ except ImportError:
 
 from distutils.sysconfig import get_python_lib
 from yolk.metadata import get_metadata
-from yolk.yolklib import get_highest_version, Distributions
+from yolk import yolklib
 from yolk.pypi import CheeseShop
 from yolk.setuptools_support import get_download_uri, get_pkglist
 from yolk.utils import run_command, command_successful
@@ -232,13 +233,14 @@ class Yolk(object):
 
         """
         if self.project_name:
-            # Check for a single package
             pkg_list = [self.project_name]
         else:
-            # Check for every installed package
             pkg_list = get_pkglist()
 
-        for (project_name, version, newest) in _updates(pkg_list, self.pypi):
+        for (project_name, version, newest) in _updates(
+                pkg_list,
+                self.pypi,
+                user_installs_only=self.options.user):
             print('{} {} ({})'.format(project_name,
                                       version,
                                       newest))
@@ -256,14 +258,14 @@ class Yolk(object):
 
         """
         if self.project_name:
-            # Check for a single package
             pkg_list = [self.project_name]
         else:
-            # Check for every installed package
             pkg_list = get_pkglist()
 
         names = [values[0]
-                 for values in _updates(pkg_list, self.pypi)]
+                 for values in _updates(pkg_list,
+                                        self.pypi,
+                                        user_installs_only=self.options.user)]
         if names:
             subprocess.call(
                 [sys.executable, '-m', 'pip', 'install', '--upgrade'] +
@@ -282,22 +284,21 @@ class Yolk(object):
 
         """
         # Search for any plugins with active CLI options with add_column()
-        # method
+        # method.
         plugins = self.get_plugin('add_column')
 
         # Some locations show false positive for 'development' packages:
         ignores = ['/UNIONFS', '/KNOPPIX.IMG']
 
-        # Check if we're in a workingenv
-        # See http://cheeseshop.python.org/pypi/workingenv.py
+        # See http://cheeseshop.python.org/pypi/workingenv.py for details.
         workingenv = os.environ.get('WORKING_ENV')
         if workingenv:
             ignores.append(workingenv)
 
-        dists = Distributions()
         results = None
-        for (dist, active) in dists.get_distributions(show, self.project_name,
-                                                      self.version):
+        for (dist, active) in yolklib.get_distributions(show,
+                                                        self.project_name,
+                                                        self.version):
             metadata = get_metadata(dist)
             for prefix in ignores:
                 if dist.location.startswith(prefix):
@@ -385,18 +386,17 @@ class Yolk(object):
                 '{} ({}){} {}'.format(metadata['Name'], version, active_status,
                                       development_status))
         else:
-            # Need intelligent justification
+            # Need intelligent justification.
             print(metadata['Name'].ljust(15) + ' - ' + version.ljust(12) +
                   ' - ' + status)
         if fields:
-            # Only show specific fields, using case-insensitive search
+            # Only show specific fields, using case-insensitive search.
             fields = [s.lower() for s in fields]
             for field in metadata.keys():
                 if field.lower() in fields:
                     print('    {}: {}'.format(field, metadata[field]))
             print()
         elif show_metadata:
-            # Print all available metadata fields
             for field in metadata.keys():
                 if field != 'Name' and field != 'Summary':
                     print('    {}: {}'.format(field, metadata[field]))
@@ -503,7 +503,7 @@ class Yolk(object):
             else:
                 version = self.all_versions[0]
         if self.options.file_type == 'all':
-            # Search for source, egg, and svn
+            # Search for source, egg, and svn.
             self.print_download_uri(version, True)
             self.print_download_uri(version, False)
             self.print_download_uri('dev', True)
@@ -530,7 +530,7 @@ class Yolk(object):
         if version == 'dev':
             source = True
 
-        # Use setuptools monkey-patch to grab url
+        # Use setuptools monkey-patch to grab url.
         url = get_download_uri(self.project_name, version, source,
                                self.options.pypi_index)
         if url:
@@ -542,7 +542,6 @@ class Yolk(object):
         @returns: 0 = success or 1 if failed download
 
         """
-        # Default type to download
         source = True
         directory = '.'
 
@@ -873,17 +872,16 @@ class Yolk(object):
 
         arg_str = self.pkg_spec
         if '==' not in arg_str:
-            # No version specified
+            # No version specified.
             project_name = arg_str
             version = None
         else:
             (project_name, version) = arg_str.split('==')
             project_name = project_name.strip()
             version = version.strip()
-        # Find proper case for package name
+        # Find proper case for package name.
         if want_installed:
-            dists = Distributions()
-            project_name = dists.case_sensitive_name(project_name)
+            project_name = yolklib.case_sensitive_name(project_name)
         else:
             (project_name, all_versions) = self.pypi.query_versions_pypi(
                 project_name)
@@ -902,9 +900,6 @@ def setup_parser():
     @returns: parser.ArgumentParser
 
     """
-    # pylint: disable-msg=C0301
-    # line too long
-
     parser = argparse.ArgumentParser()
 
     parser.add_argument('--version', action='store_true', dest='yolk_version',
@@ -1080,16 +1075,14 @@ def validate_pypi_opts(parser):
             return pkg_spec
 
 
-def _updates(names, pypi):
+def _updates(names, pypi, user_installs_only):
     """Return updates."""
-    dists = Distributions()
-
     from multiprocessing.pool import ThreadPool
 
     def worker_function(pkg):
-        for (dist, active) in dists.get_distributions(
+        for (dist, active) in yolklib.get_distributions(
                 'all', pkg,
-                dists.get_highest_installed(pkg)):
+                yolklib.get_highest_installed(pkg)):
 
             (project_name, versions) = pypi.query_versions_pypi(
                 dist.project_name)
@@ -1100,12 +1093,22 @@ def _updates(names, pypi):
 
     for (pkg, dist, project_name, versions) in pool.map(worker_function,
                                                         names):
+        try:
+            if (
+                user_installs_only and
+                not dist.location.startswith(site.getusersitepackages())
+            ):
+                continue
+        except AttributeError:
+            # Probably inside a virtualenv.
+            pass
+
         if versions:
             # PyPI returns them in chronological order,
             # but who knows if its guaranteed in the API?
             # Make sure we grab the highest version:
 
-            newest = get_highest_version(versions)
+            newest = yolklib.get_highest_version(versions)
             if newest != dist.version:
                 # We may have newer than what PyPI knows about.
                 if (
