@@ -11,6 +11,7 @@ Desc     : Return metadata for Python distribution installed by setuptools
 
 """
 
+import collections
 import email
 
 
@@ -23,15 +24,21 @@ def get_metadata(dist):
     @returns: dict of metadata or None
 
     """
-    if not dist.has_metadata('PKG-INFO'):
-        return
+    metadata = collections.OrderedDict()
+
+    if dist.has_metadata('PKG-INFO'):
+        text = dist.get_metadata('PKG-INFO')
+    elif dist.has_metadata('METADATA'):
+        text = dist.get_metadata('METADATA')
+    else:
+        return metadata
 
     try:
-        metadata = {}
-        msg = email.message_from_string(dist.get_metadata('PKG-INFO'))
-        for header in [l for l in msg._headers]:
+        message = email.message_from_string(text)
+        for header in [l for l in message._headers]:
             metadata[header[0]] = header[1]
     except IOError:
-        # no egg-file, installed using other package manager
+        # No egg-file, installed using other package manager.
         pass
+
     return metadata
